#[non_exhaustive]pub enum CertifiedCurveSurfaceIntersection3 {
Complete {
intersections: Vec<TransverseCurveSurfaceIntersection3>,
visited_nodes: u32,
},
Unresolved {
intersections: Vec<TransverseCurveSurfaceIntersection3>,
candidate_boxes: Vec<CurveSurfaceParameterBox>,
visited_nodes: u32,
},
}Expand description
Certified curve/surface query outcome.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Complete
Every candidate box was excluded or proved to contain one transverse root.
Fields

intersections: Vec<TransverseCurveSurfaceIntersection3>Pairwise-disjoint transverse-root certificates.
Unresolved
One or more boxes could not be proved or excluded within policy.
Fields

intersections: Vec<TransverseCurveSurfaceIntersection3>Transverse roots that were proved before another box remained unresolved.

candidate_boxes: Vec<CurveSurfaceParameterBox>Conservative boxes that may contain singular, tangential, boundary, or unresolved roots.