#[non_exhaustive]pub enum ExtremaRefusal {
Unsupported,
Evaluation,
Budget,
}Expand description
Why an extremum could not be found.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
A curve or surface family this module has no image bounds for.
Evaluation
A piece could not be evaluated.
Budget
The search exceeded its work budget before reaching the accuracy.