pub fn trace_section_pcurves(
surface: &Surface,
other: &Surface,
window: (Point2, Point2),
) -> Result<Vec<ImplicitCurve2>, ExactIntersectionRefusal>Expand description
Every component of the section of surface by other in a window of
surface’s parameters, as curves in those parameters.
A window a whole turn wide in a periodic parameter wraps.
Errors
As crate::implicit_surface_intersection; Disjoint is not an
error here (the list is empty).