Struct BoundedSurface

pub struct BoundedSurface {
    pub surface: BSplineSurface,
    pub deviation_upper_bound: Scalar,
}
A surface changed within a stated bound.

Fields

surface: BSplineSurface

The transformed surface.

deviation_upper_bound: Scalar

Upper bound on the distance between the original and transformed surfaces at every parameter, in model units (computed in f64).