Struct FundamentalForm

pub struct FundamentalForm {
    pub e: Scalar,
    pub f: Scalar,
    pub g: Scalar,
}
Coefficients (e, f, g) of a quadratic fundamental form.

Fields

e: Scalar

First diagonal coefficient (E for the first form, e for the second).

f: Scalar

Mixed coefficient (F for the first form, f for the second).

g: Scalar

Second diagonal coefficient (G for the first form, g for the second).