pub struct FundamentalForm {
pub e: Scalar,
pub f: Scalar,
pub g: Scalar,
}Expand description
Coefficients (e, f, g) of a quadratic fundamental form.
Fields
e: ScalarFirst diagonal coefficient (E for the first form, e for the second).
f: ScalarMixed coefficient (F for the first form, f for the second).
g: ScalarSecond diagonal coefficient (G for the first form, g for the second).